AssertPass class

Returned after an Expect has succeeded.

Inheritance

Constructors

AssertPass()

Properties

childIndicator String
For best results, make this 3 characters
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
index int?
getter/setter pairinherited
message String?
getter/setter pairinherited
printer ↔ void Function(String message)
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacer String
getter/setter pairinherited

Methods

formatMessage() String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
report({int spacerCount = 0}) → void
override
setSpacer({int spacerCount = 0}) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited