Context<ExpectedType> class
Context is how information can be passed from stage to stage.
This is passed as an argument on each stage and and is an inheritable object that is passed from parent to children. By default, test has an actual value, an expected value, and an additional map to pass information through ad-hoc. The default Context is called by using the TestRunnerDefault constructor.
Constructors
- Context()
- Context.deepCopy(Context siblingContext)
Properties
- actual ↔ ExpectedType?
-
getter/setter pair
- contextualType → String
-
no setter
-
entries
→ Iterable<
MapEntry< String, dynamic> > -
The map entries of this Map.
no setteroverride
- expected ↔ ExpectedType?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Whether there is no key/value pair in the map.
no setteroverride
- isNotEmpty → bool
-
Whether there is at least one key/value pair in the map.
no setteroverride
-
keys
→ Iterable<
String> -
The keys of this Map.
no setteroverride
- length → int
-
The number of key/value pairs in the map.
no setteroverride
-
mocks
→ MockCollection<
MockBase> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
no setter
- values → Iterable
-
The values of this Map.
no setteroverride
Methods
-
addAll(
Map< String, dynamic> other) → void -
Adds all key/value pairs of
otherto this map.override -
addEntries(
Iterable< MapEntry< newEntries) → voidString, dynamic> > -
Adds all key/value pairs of
newEntriesto this map.override -
cast<
RK, RV> () → Map< RK, RV> -
Provides a view of this map as having
RKkeys andRVinstances, if necessary.override -
clear(
) → void -
Removes all entries from the map.
override
-
containsKey(
Object? key) → bool -
Whether this map contains the given
key.override -
containsValue(
Object? value) → bool -
Whether this map contains the given
value.override -
copy(
Context parentContext) → void -
copyExtraParams(
Context contextToCopyFrom) → void - Copies extra parameters from parent group to child Remember to include this if you create and set named parameters outside of using the context map.
-
forEach(
void action(String key, dynamic value)) → void -
Applies
actionto each key/value pair of the map.override -
map<
K2, V2> (MapEntry< K2, V2> convert(String key, dynamic value)) → Map<K2, V2> -
Returns a new map where all entries of this map are transformed by
the given
convertfunction.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putIfAbsent(
String key, dynamic ifAbsent()) → dynamic -
Look up the value of
key, or add a new entry if it isn't there.override -
remove(
Object? key) → dynamic -
Removes
keyand its associated value, if present, from the map.override -
removeWhere(
bool test(String key, dynamic value)) → void -
Removes all entries of this map that satisfy the given
test.override -
setContextualInformation(
{required String title, required String contextualType}) → void -
toString(
) → String -
A string representation of this object.
inherited
-
update(
String key, dynamic update(dynamic value), {dynamic ifAbsent()?}) → dynamic -
Updates the value for the provided
key.override -
updateAll(
dynamic update(String key, dynamic value)) → void -
Updates all values.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
Object? key) → dynamic -
The value for the given
key, ornullifkeyis not in the map.override -
operator []=(
String key, dynamic value) → void -
Associates the
keywith the givenvalue.override