MockBase<T> class abstract

MockBase behaves as a template for all Mock implementations. The default implementation in Cake is MockableFunction and MockableFunctionOf. But you can create your own Mocks by extending this class.

For examples on how to use this with a mock, see MockableFunction.

Implementers

Constructors

MockBase()

Properties

callArgs List<CallArgs?>
getter/setter pair
callCount int
getter/setter pair
called bool
no setter
hashCode int
The hash code for this object.
no setterinherited
history List<CallArgs?>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value ↔ T
getter/setter pair

Methods

call() → T
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → void
reset() → void
resume() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited