throwNextCall method

void throwNextCall([
  1. Exception? e
])
inherited

The next time this function is called, throw e. If e is not provided, this will throw 'Mocked exception'.

Implementation

void throwNextCall([Exception? e]) {
  _throwNextCall = true;
  _e = e;
}