Result mixin

For better formatting when output by the Printer

Mixin applications

Properties

childIndicator String
For best results, make this 3 characters
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
printer ↔ void Function(String message)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacer String
getter/setter pair

Methods

formatMessage() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
report({int spacerCount = 0}) → void
setSpacer({int spacerCount = 0}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited