TestMessage class

Outputs a message to the console

Used for overall system messages or errors.

Constructors

TestMessage(String testTitle, {String? message})

Properties

childIndicator String
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
message String?
getter/setter pair
printer ↔ void Function(String message)
getter/setter pairoverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacer String
getter/setter pairinherited
testTitle String
getter/setter pairinherited

Methods

formatMessage() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
report({int spacerCount = 0}) → void
override
setSpacer({int spacerCount = 0}) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited