TestRunnerDefault class

Create a TestRunner with a Default Context with no or dynamic ExpectedType

The root node for any tests. Automatically runs once created. Do not include TestRunners inside other Groups.

Inheritance

Constructors

TestRunnerDefault(String _title, List<Contextual<Context>> children, {TestOptions? options, FutureOr<void> setup(Context test)?, FutureOr<void> teardown(Context test)?, OnComplete? onComplete})
TestRunnerDefault.skip(String _title, List<Contextual<Context>> children, {TestOptions? options, FutureOr<void> setup(Context test)?, FutureOr<void> teardown(Context test)?, OnComplete? onComplete})
Skipped. This will not run any of the stages or children within this test runner.

Properties

children List<Contextual<Context>>
finalinherited
contextualType String
no setterinherited
failures int
no setterinherited
filterSettings FilterSettings
finalinherited
hashCode int
The hash code for this object.
no setterinherited
neutrals int
no setterinherited
onComplete OnComplete?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setup FutureOr<void> Function(Context test)?
finalinherited
skip bool
finalinherited
successes int
no setterinherited
teardown FutureOr<void> Function(Context test)?
finalinherited
testFailCount int
getter/setter pairinherited
testNeutralCount int
getter/setter pairinherited
testSuccessCount int
getter/setter pairinherited
total int
no setterinherited

Methods

complete([String? message]) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
report(FilterSettings filterSettings) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited