TestRunnerOf<ExpectedType> class
Create a TestRunner with a Default Context of an ExpectedType
The root node for any tests. Automatically runs once created. Do not include TestRunners inside other Groups.
- Inheritance
-
- Object
- Contextual<
Context< ExpectedType> > - TestRunnerOf
Constructors
-
TestRunnerOf(String _title, List<
Contextual< children, {TestOptions? options, FutureOr<Context< >ExpectedType> >void> setup(Context<ExpectedType> test)?, FutureOr<void> teardown(Context<ExpectedType> test)?, OnComplete? onComplete}) -
TestRunnerOf.skip(String _title, List<
Contextual< children, {TestOptions? options, FutureOr<Context< >ExpectedType> >void> setup(Context<ExpectedType> test)?, FutureOr<void> teardown(Context<ExpectedType> test)?, OnComplete? onComplete}) - Skipped. This will not run any of the stages or children within this test runner.
Properties
-
children
→ List<
Contextual< Context< >ExpectedType> > -
finalinherited
- contextualType → String
-
no setterinherited
- failures → int
-
no setterinherited
- filterSettings → FilterSettings
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- neutrals → int
-
no setterinherited
- onComplete → OnComplete?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
setup
→ FutureOr<
void> Function(Context<ExpectedType> test)? -
finalinherited
- skip → bool
-
finalinherited
- successes → int
-
no setterinherited
-
teardown
→ FutureOr<
void> Function(Context<ExpectedType> test)? -
finalinherited
- testFailCount ↔ int
-
getter/setter pairinherited
- testNeutralCount ↔ int
-
getter/setter pairinherited
- testSuccessCount ↔ int
-
getter/setter pairinherited
- total → int
-
no setterinherited
Methods
-
complete(
[String? message]) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
report(
FilterSettings filterSettings) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited