OnComplete typedef
OnComplete =
void Function(String message)
Callback for when all tests have finished within a test runner
Returns output summary of tests, identical to what is returned by Printer.summary()
Implementation
typedef OnComplete = void Function(String message);