TestOptions class
Options are an inheritable object that can be set on a TestRunner, Group, or Test. Any child settings will override parent settings, if set.
Constructors
- TestOptions({bool? failOnFirstExpect})
-
const
Properties
- failOnFirstAssert → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
mapParent(
TestOptions parent) → TestOptions -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited